/*---------------------------------------------------------
CON EL USUARIO BDSALUD CREAMOS LAS TABLAS
PARA EL APLICATIVO Big Data de salut
-----------------------------------------------------------*/

/* ----------------------------------
      01 - CREACION TABLA PAISES
-----------------------------------*/
DROP TABLE BDSALUD.PAISES CASCADE CONSTRAINTS;

CREATE TABLE BDSALUD.PAISES
  (
    COD         VARCHAR2(2)   NOT NULL,
    DENOM       VARCHAR2(50)  NOT NULL,
    ANIOUE		  INTEGER	              ,
    HAB		      CHAR(1) DEFAULT 'S' NOT NULL,
 -- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT CK_PAIS_HAB CHECK (HAB in ('S', 'N')),
    CONSTRAINT PK_PAISES PRIMARY KEY (COD)
  )
  TABLESPACE TS_BDSALUD;

/* ----------------------------------
      02 - CREACIN TABLA PERSONAS
-----------------------------------*/
DROP TABLE BDSALUD.PERSONAS CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.PERSONAS 
  (
    ID    	      INTEGER       NOT NULL,
    IDE           VARCHAR2(20)  NOT NULL,
    NOMBRE	      VARCHAR2(20)  NOT NULL,
    APELLIDO1		  VARCHAR2(20)		  ,
    APELLIDO2		  VARCHAR2(20)		  ,
    FECHANAC      DATE	 	     NOT NULL,
    CODPAIS       VARCHAR2(2)            ,
    SEXO          CHAR(1)        NOT NULL,
    FECHABAJ      DATE	  	     		  ,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT  PK_PERSONAS  PRIMARY KEY (ID),
    CONSTRAINT  FK_PERSONAS_PAISES FOREIGN KEY (CODPAIS) 				
                REFERENCES BDSALUD.PAISES (COD),
    CONSTRAINT CK_PERSONAS_SEXO CHECK (SEXO in ('V', 'M')),
    CONSTRAINT CK_PERSONAS_FECHAS CHECK (FECHANAC <=  FECHABAJ)
      
  )
  TABLESPACE TS_BDSALUD;
  
 -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_PERSONAS;
  CREATE SEQUENCE BDSALUD.SE_PERSONAS INCREMENT BY 1 START WITH 1;
  
/* ---------------------------------------
      03 - CREACIN TABLA CENTROS_SALUD
------------------------------------------*/
DROP TABLE BDSALUD.CENTROS_SALUD CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.CENTROS_SALUD 
  (
    ID    	      INTEGER       NOT NULL,
    CODPAIS       VARCHAR2(2)   NOT NULL,
    CODCENTRO     VARCHAR2(10)  NOT NULL,
    NOMBRE			 VARCHAR2(50)           ,
    TELEFONO		 VARCHAR2(20)	          ,
    CORREO			 VARCHAR2(30)    		    ,
    FECHABAJ     	 DATE	  	     		    ,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT  PK_CENTROS_SALUD PRIMARY KEY (ID),
    CONSTRAINT  FK_CENTROSALUD_PAISES FOREIGN KEY (CODPAIS) 			           
		REFERENCES BDSALUD.PAISES (COD),
    CONSTRAINT  UQ_CENTROSALUD_AK UNIQUE (CODPAIS,CODCENTRO)
      
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_CENTROS_SALUD;

  CREATE SEQUENCE BDSALUD.SE_CENTROS_SALUD INCREMENT BY 1 START WITH 1;

/* ---------------------------------------
      04 - CREACIN TABLA MOTIVOS_BAJA
------------------------------------------*/
DROP TABLE BDSALUD.MOTIVOS_BAJA CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.MOTIVOS_BAJA 
  (
    ID    		INTEGER       NOT NULL,
    DENOM       VARCHAR2(50)  NOT NULL,
    HAB		CHAR(1) DEFAULT 'S' NOT NULL,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT CK_MOTBAJA_HAB CHECK (HAB in ('S', 'N')),
    CONSTRAINT PK_MOTIVOS_BAJA PRIMARY KEY (ID)      
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_MOTIVOS_BAJA;

  CREATE SEQUENCE BDSALUD.SE_MOTIVOS_BAJA MINVALUE 0 INCREMENT BY 1 START WITH 0;

/* ---------------------------------------
      05 - CREACIN TABLA CIUDADANOS
------------------------------------------*/
DROP TABLE BDSALUD.CIUDADANOS CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.CIUDADANOS 
  (
    ID    		      INTEGER       NOT NULL,
    IDPERSONA         INTEGER       NOT NULL,
    IDCENTRO          INTEGER       NOT NULL,
    FECHABAJ     	    DATE	  	          	 ,
    CODUSU		        VARCHAR2(16)          ,
    TELEFDOM		      VARCHAR2(20)	        ,
    TELEFMOVIL	    	VARCHAR2(20)	        ,
    CORREO		     	  VARCHAR2(30)	        ,
    FECHAALT          DATE DEFAULT SYSDATE  ,
    IDMOTBAJ		      NUMBER                ,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT  PK_CIUDADANOS PRIMARY KEY (ID),
    CONSTRAINT  FK_CIUDADANOS_PERSONAS FOREIGN KEY (IDPERSONA) 			           
		REFERENCES BDSALUD.PERSONAS (ID),
    CONSTRAINT  FK_CIUDADANOS_CENTROSSALUD FOREIGN KEY (IDCENTRO) 			     
		REFERENCES BDSALUD.CENTROS_SALUD (ID),
    CONSTRAINT  FK_CIUDADANOS_MOTIVOSBAJA FOREIGN KEY (IDMOTBAJ) 			           
		REFERENCES BDSALUD.MOTIVOS_BAJA (ID),
    CONSTRAINT  UQ_CIUDADANOS_AK UNIQUE (IDPERSONA,IDCENTRO,FECHABAJ),
    CONSTRAINT CK_CIUDADANOS_FECHAS CHECK (FECHAALT <=  FECHABAJ)
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_CIUDADANOS;

  CREATE SEQUENCE BDSALUD.SE_CIUDADANOS INCREMENT BY 1 START WITH 1;
  


/* ---------------------------------------
      06 - CREACIN TABLA HIS_SALUD
------------------------------------------*/
DROP TABLE BDSALUD.HIS_SALUD CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.HIS_SALUD
  (
    ID            INTEGER       NOT NULL,
    IDCIU         INTEGER       NOT NULL,
    ANIO          INTEGER       NOT NULL,
    VISITASMED    INTEGER       NOT NULL,
    ENFLEVS    	  INTEGER       NOT NULL,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)  ,
    DATMOD      DATE                 ,
--
    CONSTRAINT  PK_HIS_SALUD PRIMARY KEY (ID),
    CONSTRAINT  FK_HISSALUD_CIUDADANOS FOREIGN KEY (IDCIU)
	           REFERENCES BDSALUD.CIUDADANOS (ID),
    CONSTRAINT  UQ_HISSALUD_AK UNIQUE (IDCIU,ANIO)      
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_HIS_SALUD;

  CREATE SEQUENCE BDSALUD.SE_HIS_SALUD INCREMENT BY 1 START WITH 1;

/* ---------------------------------------
      07 - CREACIN TABLA ENFERMEDADES
------------------------------------------*/
DROP TABLE BDSALUD.ENFERMEDADES CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.ENFERMEDADES 
  (
    ID    	INTEGER       NOT NULL,
    DENOM   VARCHAR2(50)  NOT NULL,
    COLEST  VARCHAR2(30),    
    HAB		CHAR(1)DEFAULT 'S' NOT NULL,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT CK_ENFERMEDADES_HAB CHECK (HAB in ('S', 'N')),
    CONSTRAINT PK_ENFERMEDADES PRIMARY KEY (ID)      
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_ENFERMEDADES;

  CREATE SEQUENCE BDSALUD.SE_ENFERMEDADES INCREMENT BY 1 START WITH 1;

/* --------------------------------------------
      08 - CREACIN HISSALUD_ENF QUE RELACIONA 
           HISTORIA SALUD Y ENFERMEDAD.
-----------------------------------------------*/
DROP TABLE BDSALUD.HISSALUD_ENF CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.HISSALUD_ENF
  (
    IDHIS 		INTEGER       NOT NULL,
    IDENF 		INTEGER       NOT NULL,
    -- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
 --
    CONSTRAINT PK_HISSALUD_ENF PRIMARY KEY (IDHIS,IDENF)  
  )
  TABLESPACE TS_BDSALUD;

/* ---------------------------------------
      09 - CREACIN TABLA ACT_DIARIA
------------------------------------------*/
DROP TABLE BDSALUD.ACT_DIARIA CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.ACT_DIARIA
  (
    IDCIU         INTEGER       NOT NULL,
    FECHA         DATE DEFAULT SYSDATE NOT NULL,
    PASOS         INTEGER DEFAULT 0,
    CALORIAS	    INTEGER DEFAULT 0,
    HPOCACT	      INTEGER DEFAULT 0,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT  PK_ACT_DIARIA PRIMARY KEY (IDCIU,FECHA),
    CONSTRAINT  FK_ACT_DIARIA_CIUDADANOS FOREIGN KEY (IDCIU)
	           REFERENCES BDSALUD.CIUDADANOS (ID)
  )
  TABLESPACE TS_BDSALUD;
  
-- CREACIN NDICE OPTIMIZACIN ACCESO A DATOS
  CREATE INDEX BDSALUD.NC_ANIO_ACTDIARIA ON
BDSALUD.ACT_DIARIA(EXTRACT(YEAR FROM FECHA));

/* ----------------------------------
   CREACIN TABLA LOGS 
-----------------------------------*/ 
DROP TABLE BDSALUD.LOGS CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.LOGS 
  ( 
    ID    		 INTEGER       NOT NULL,
    NOMPRO       VARCHAR2(50)  NOT NULL,
    LOGPAR       VARCHAR2(500)         ,
    RSP 		     VARCHAR2(500) NOT NULL,
    TIPLOG       CHAR(1)       NOT NULL,
    FECHALOG     DATE   DEFAULT SYSDATE,
    USULOG       VARCHAR2(15)  NOT NULL,
    CONSTRAINT PK_LOGS PRIMARY KEY (ID)      
  )
  TABLESPACE TS_BDSALUD;

  -- CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_LOGS;
  CREATE SEQUENCE BDSALUD.SE_LOGS INCREMENT BY 1 START WITH 1;


/* ----------------------------------
   CREACIN TABLA ERRORES 
-----------------------------------*/ 
DROP TABLE BDSALUD.ERRORES CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.ERRORES 
  ( 
    ID    	INTEGER       NOT NULL,
    DESCRIP     VARCHAR2(250)     ,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT PK_ERRORES PRIMARY KEY (ID)      
  )
  TABLESPACE TS_BDSALUD;

  --CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_ERRORES;
  CREATE SEQUENCE BDSALUD.SE_ERRORES INCREMENT BY 1 START WITH 1;
  
  /* ----------------------------------
   CREACIN TABLA EST_ANU_SALUD (EUROPA)
-----------------------------------*/ 
DROP TABLE BDSALUD.EST_ANU_SALUD CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.EST_ANU_SALUD 
  ( 
    ID      	INTEGER       NOT NULL,
    ANIO      INTEGER       NOT NULL,
    CIUSCONA  INTEGER DEFAULT 0,
    CALSCIUS  INTEGER DEFAULT 0,
    PASCIUS	  INTEGER DEFAULT 0,
    HPACIUS   INTEGER DEFAULT 0,
    CIUSECAR  INTEGER DEFAULT 0,
    CIUSEDEG  INTEGER DEFAULT 0,
    CIUSECAN  INTEGER DEFAULT 0,
    ELEVCIUS  INTEGER DEFAULT 0,
    PERMAXCAL INTEGER,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT PK_EST_ANU_SALUD PRIMARY KEY (ID),
    CONSTRAINT  UQ_EST_ANU_SALUD_AK UNIQUE (ANIO)    
  )
  TABLESPACE TS_BDSALUD;

  --CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_EST_ANU_SALUD;
  CREATE SEQUENCE BDSALUD.SE_EST_ANU_SALUD INCREMENT BY 1 START WITH 1;

/* ----------------------------------
   CREACIN TABLA EST_ANU_PAI_SALUD (PAISES) 
-----------------------------------*/ 
DROP TABLE BDSALUD.EST_ANU_PAI_SALUD CASCADE CONSTRAINTS;
CREATE TABLE BDSALUD.EST_ANU_PAI_SALUD 
  ( 
    ID      	INTEGER       NOT NULL,
    ANIO      INTEGER       NOT NULL,
    CODPAIS   VARCHAR2(2)   NOT NULL,
    CIUSCONA  INTEGER DEFAULT 0,
    CALSCIUS  INTEGER DEFAULT 0,
    PASCIUS	  INTEGER DEFAULT 0,
    HPACIUS   INTEGER DEFAULT 0,
    CIUSECAR  INTEGER DEFAULT 0,
    CIUSEDEG  INTEGER DEFAULT 0,
    CIUSECAN  INTEGER DEFAULT 0,
    ELEVCIUS  INTEGER DEFAULT 0,
    PERMAXCAL INTEGER,
-- Campos auditora   
    USUINS      VARCHAR2(30)  NOT NULL,
    DATINS      DATE DEFAULT SYSDATE NOT NULL,
    USUMOD      VARCHAR2(30)         ,
    DATMOD      DATE                 ,
--
    CONSTRAINT PK_EST_ANU_PAI_SALUD PRIMARY KEY (ID),
    CONSTRAINT  FK_ESTANUPAISALUD_PAISES FOREIGN KEY (CODPAIS) 			           
		REFERENCES BDSALUD.PAISES (COD),
    CONSTRAINT  UQ_EST_ANU_PAI_SALUD_AK UNIQUE (ANIO,CODPAIS)    
  )
  TABLESPACE TS_BDSALUD;

  --CREACIN DE SECUENCIA PARA ID --
  DROP SEQUENCE BDSALUD.SE_EST_ANU_PAI_SALUD;
  CREATE SEQUENCE BDSALUD.SE_EST_ANU_PAI_SALUD INCREMENT BY 1 START WITH 1;
