CREATE OR REPLACE PACKAGE ACT_PERSONA as

PROCEDURE PERSONAS_Add(
                          p_ide                IN     PERSONAS.IDE%TYPE
                         ,p_nombre             IN     PERSONAS.NOMBRE%TYPE
                         ,p_apellido1          IN     PERSONAS.APELLIDO1%TYPE
                         ,p_apellido2          IN     PERSONAS.APELLIDO2%TYPE
                         ,p_fechanac           IN     PERSONAS.FECHANAC%TYPE
                         ,p_codpais            IN     PERSONAS.CODPAIS%TYPE
                         ,p_sexo               IN     PERSONAS.SEXO%TYPE
                         ,p_id                 OUT    PERSONAS.ID%TYPE
                         ,p_RSP                OUT VARCHAR2 );
                         
PROCEDURE PERSONAS_Update(
                          p_id                 IN     PERSONAS.ID%TYPE
                         ,p_ide                IN     PERSONAS.IDE%TYPE
                         ,p_nombre             IN     PERSONAS.NOMBRE%TYPE
                         ,p_apellido1          IN     PERSONAS.APELLIDO1%TYPE
                         ,p_apellido2          IN     PERSONAS.APELLIDO2%TYPE
                         ,p_fechanac           IN     PERSONAS.FECHANAC%TYPE
                         ,p_codpais            IN     PERSONAS.CODPAIS%TYPE
                         ,p_sexo               IN     PERSONAS.SEXO%TYPE
                         ,p_RSP                OUT VARCHAR2 );
PROCEDURE PERSONAS_Delete(
                          p_id                 IN     PERSONAS.ID%TYPE
                         ,p_fechabaj           IN     PERSONAS.FECHABAJ%TYPE
                         ,p_RSP                OUT VARCHAR2 );
   
END ACT_PERSONA;
/


CREATE OR REPLACE PACKAGE BODY ACT_PERSONA AS

  /* ***************************************************************************
   *  Descripcin: Realiza el alta de una persona en la BD.
   *  Parametros entrada (datos a insertar):
   *   p_ide       - N de indentificacin de persona
   *   p_nombre    - Nombre de persona
   *   p_apellido1 - Primer apellido
   *   p_apellido2 - Segundo apellido
   *   p_fechanac  - Fecha de nacimiento 
   *   p_codpais   - Pais de nacimiento
   *   p_sexo      - Sexo (M = Masculino, F = Fememnino)
   *  Parametros de salida: 
   *   p_id  -  Devuelve nuevo identificador de persona
   *   p_RSP -  Devuelve:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         29-10-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE PERSONAS_Add(
                          p_ide                IN     PERSONAS.IDE%TYPE
                         ,p_nombre             IN     PERSONAS.NOMBRE%TYPE
                         ,p_apellido1          IN     PERSONAS.APELLIDO1%TYPE
                         ,p_apellido2          IN     PERSONAS.APELLIDO2%TYPE
                         ,p_fechanac           IN     PERSONAS.FECHANAC%TYPE
                         ,p_codpais            IN     PERSONAS.CODPAIS%TYPE
                         ,p_sexo               IN     PERSONAS.SEXO%TYPE
                         ,p_id                 OUT    PERSONAS.ID%TYPE
                         ,p_RSP                OUT    VARCHAR2 )
    IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;

    -- Declaracin de excepciones
      er_null             EXCEPTION;
      er_notfndPais       EXCEPTION;
      er_duplicado        EXCEPTION;
   BEGIN
      p_id := NULL;
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'PERSONAS_Add';    
      v_log :=    'p_ide ->' || p_ide                
                ||', p_nombre ->' || p_nombre
                ||', p_apellido1 ->' || p_apellido1
                ||', p_apellido2 ->' || p_apellido2
                ||', p_fechanac  ->' || p_fechanac
                ||', p_codpais ->' || p_codpais
                ||', p_sexo ->' ||p_sexo;                
      p_RSP := ' ';       
   
      
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','S',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF p_ide IS NULL
         OR p_nombre IS NULL        
         OR p_fechanac IS NULL
         OR p_sexo IS NULL
         THEN
          RAISE er_null;
      END IF;
  
      -- Verificar si Identificador de persona est duplicado
      IF UTILIDADES.PERSONAS_Found(p_ide)='S' THEN
            RAISE er_duplicado;
      END IF;

      -- Verificar si el PAIS existe en la comunidad europea
      IF  NOT p_codpais IS NULL THEN
         IF UTILIDADES.PAISES_Found(p_codpais)='N' THEN
            RAISE er_notfndPais;
         END IF;
      END IF;
      
      -- Generamos identificador de persona desde secuencuencia
      SELECT BDSALUD.SE_PERSONAS.nextval INTO p_id FROM DUAL; 
      
      INSERT INTO PERSONAS(ID, IDE, NOMBRE, APELLIDO1, APELLIDO2, FECHANAC, CODPAIS, SEXO)
         VALUES (p_id, p_ide, p_nombre, p_apellido1, p_apellido2, p_fechanac, p_codpais,p_sexo);         
             
      -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      v_log := v_log || ', p_id ->' || p_id;                
      p_RSP := 'OK';
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
      COMMIT;
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN er_notfndPais THEN
         v_err_num := 2;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
       WHEN er_duplicado THEN
         v_err_num := 3;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END PERSONAS_Add;   
   /* ***************************************************************************
   *  Descripcin: Modifica los datos de una persona en la BD.
   *  Parametros entrada:
   *   p_id        - Identificador de persona a modificar
   *   p_ide       - N de indentificacin de persona
   *   p_nombre    - Nombre de persona
   *   p_apellido1 - Primer apellido
   *   p_apellido2 - Segundo apellido
   *   p_fechanac  - Fecha de nacimiento 
   *   p_codpais   - Pais de nacimiento
   *   p_sexo      - Sexo (M = Masculino, F = Fememnino)
   *  Parametros de salida: 
   *   p_RSP -  Devuelve:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         29-10-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE PERSONAS_Update(
                          p_id                 IN     PERSONAS.ID%TYPE
                         ,p_ide                IN     PERSONAS.IDE%TYPE
                         ,p_nombre             IN     PERSONAS.NOMBRE%TYPE
                         ,p_apellido1          IN     PERSONAS.APELLIDO1%TYPE
                         ,p_apellido2          IN     PERSONAS.APELLIDO2%TYPE
                         ,p_fechanac           IN     PERSONAS.FECHANAC%TYPE
                         ,p_codpais            IN     PERSONAS.CODPAIS%TYPE
                         ,p_sexo               IN     PERSONAS.SEXO%TYPE
                         ,p_RSP                OUT VARCHAR2 )
    IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;

    -- Declaracin de excepciones
      er_null             EXCEPTION;
      er_notfndPais       EXCEPTION;
      er_notfndPersona    EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'PERSONAS_Update';    
      v_log :=      'p_id ->' || p_id
                ||  'p_ide ->' || p_ide                
                ||', p_nombre ->' || p_nombre
                ||', p_apellido1 ->' || p_apellido1
                ||', p_apellido2 ->' || p_apellido2
                ||', p_fechanac  ->' || p_fechanac
                ||', p_codpais ->' || p_codpais
                ||', p_sexo ->' ||p_sexo;                
      p_RSP := ' ';       
      
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','S',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF p_id IS NULL
         OR p_ide IS NULL
         OR p_nombre IS NULL        
         OR p_fechanac IS NULL
         OR p_sexo IS NULL
         THEN
          RAISE er_null;
      END IF;

      -- Verificar si el PAIS existe en la comunidad europea
      IF  NOT p_codpais IS NULL THEN
         IF UTILIDADES.PAISES_Found(p_codpais)='N' THEN
            RAISE er_notfndPais;
         END IF;
      END IF;
      
      -- Verificar si exite persona
      IF UTILIDADES.PERSONAS_Found(p_id)='N' THEN
            RAISE er_notfndPersona;
      END IF;
    
      UPDATE PERSONAS
       SET IDE = p_ide
           ,NOMBRE = p_nombre
           ,APELLIDO1 = p_apellido1
           ,APELLIDO2 = p_apellido2
           ,FECHANAC = p_fechanac
           ,CODPAIS = p_codpais
           ,SEXO = p_sexo
        WHERE ID = p_id;       
             
      -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      v_log := v_log || ', p_id ->' || p_id;                
      p_RSP := 'OK';
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
      COMMIT;
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN er_notfndPais THEN
         v_err_num := 2;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
       WHEN er_notfndPersona THEN
         v_err_num := 4;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END PERSONAS_Update;   
    /* ***************************************************************************
   *  Descripcin: Marca como dada de baja una persona en la BD.
   *  Parametros entrada:
   *   p_id        - Identificador de persona a modifica
   *   p_fechabaj  - Fecha de baja en la BD 
   *  Parametros de salida: 
   *   p_RSP -  Devuelve:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         29-10-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE PERSONAS_Delete(
                          p_id                 IN     PERSONAS.ID%TYPE
                         ,p_fechabaj           IN     PERSONAS.FECHABAJ%TYPE
                         ,p_RSP                OUT VARCHAR2 )
    IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;

    -- Declaracin de excepciones
      er_null             EXCEPTION;
      er_notfndPersona    EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'PERSONAS_Delete';    
      v_log :=      'p_id ->' || p_id
                ||', p_fechabaj  ->' || p_fechabaj;                
      p_RSP := ' ';          
      
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','S',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF p_id IS NULL
         OR p_fechabaj IS NULL
         THEN
          RAISE er_null;
      END IF;
      -- Verificar si exite persona
      IF UTILIDADES.PERSONAS_Found(p_id)='N' THEN
            RAISE er_notfndPersona;
      END IF;
    
      UPDATE PERSONAS
       SET FECHABAJ = p_fechabaj
        WHERE ID = p_id;       
             
      -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      v_log := v_log || ', p_id ->' || p_id;                
      p_RSP := 'OK';
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
      COMMIT;
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN er_notfndPersona THEN
         v_err_num := 4;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg;
         v_log := v_log || ', p_id ->' || p_id;                
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END PERSONAS_Delete;   
END ACT_PERSONA;
/
