CREATE OR REPLACE PACKAGE ESTADISTICA AS

-- Sobrecarga de procedimientos --                                     
PROCEDURE ESTANISALUD_Acu(p_datreg      IN EST_ANU_PAI_SALUD%ROWTYPE
                         ,p_RSP         OUT    VARCHAR2 );
                          
PROCEDURE ESTANIPAISALUD_Acu(p_datreg   IN EST_ANU_PAI_SALUD%ROWTYPE
                            ,p_RSP      OUT    VARCHAR2 );
                            
PROCEDURE ESTSALUD_COLUMN_Acu(p_anio         IN EST_ANU_SALUD.ANIO%TYPE
                              ,p_column      IN VARCHAR2
                              ,p_acu         IN NUMBER DEFAULT 0
                              ,p_RSP         OUT    VARCHAR2 );
                              
PROCEDURE ESTSALUD_COLUMN_Acu(p_anio         IN EST_ANU_PAI_SALUD.ANIO%TYPE
                              ,p_codpais     IN EST_ANU_PAI_SALUD.CODPAIS%TYPE
                              ,p_column      IN VARCHAR2
                              ,p_acu         IN NUMBER DEFAULT 0
                              ,p_RSP         OUT    VARCHAR2 );
                              
FUNCTION ACT_DIARIA_GetPerMaxCal(p_anio IN INTEGER)
RETURN CIUDADANOS.IDPERSONA%TYPE;

FUNCTION ACT_DIARIA_GetPerMaxCal(p_anio IN INTEGER
                                ,p_codpais IN PAISES.COD%TYPE)
RETURN CIUDADANOS.IDPERSONA%TYPE;

FUNCTION HISSALUD_ENF_GetCiusE(p_enf IN ENFERMEDADES.ID%TYPE
                               ,p_anio IN HIS_SALUD.ANIO%TYPE
                               ,p_codpais IN PAISES.COD%TYPE)
RETURN INTEGER;

FUNCTION HISSALUD_ENF_GetCiusE(p_enf IN ENFERMEDADES.ID%TYPE
                               ,p_anio IN HIS_SALUD.ANIO%TYPE)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CFound(p_idciu IN ACT_DIARIA.IDCIU%TYPE
                            ,p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CFound(p_idciu IN ACT_DIARIA.IDCIU%TYPE
                            ,p_anio IN INTEGER
                            ,p_codpais IN PAISES.COD%TYPE)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CIUSCONA(p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CALSCIUS(p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION ACT_DIARIA_PASCIUS(p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION ACT_DIARIA_HPACIUS(p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION HIS_SALUD_ELEVCIUS(p_anio IN INTEGER)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CIUSCONA(p_anio IN INTEGER
                          , p_codpais IN VARCHAR2)
RETURN INTEGER;

FUNCTION ACT_DIARIA_CALSCIUS(p_anio IN INTEGER
                           , p_codpais IN VARCHAR2)
RETURN INTEGER;

FUNCTION ACT_DIARIA_PASCIUS(p_anio IN INTEGER
                          , p_codpais IN VARCHAR2)
RETURN INTEGER;

FUNCTION ACT_DIARIA_HPACIUS(p_anio IN INTEGER
                          , p_codpais IN VARCHAR2)
RETURN INTEGER;

FUNCTION HIS_SALUD_ELEVCIUS(p_anio IN INTEGER
                          , p_codpais IN VARCHAR2)
RETURN INTEGER;

--
END ESTADISTICA;
/
CREATE OR REPLACE PACKAGE BODY ESTADISTICA AS
 -- Sobrecarga de procedimientos --
   /* ***************************************************************************
   *  Descripcin: Proporciona el valor de las columnas a contibilizar 
                   a la tabla EST_ANU_SALUD.
   *  Parametros entrada:
   *   p_datreg   - Registro con los datos a contibilizar
   *      si cantidad a acumular es mayor que 0 el trigger de columna indicada
   *       incrementa.
   *      si cantidad a acumular es menor que 0 el trigger de columna indicada
   *       decrementa.
   *  Parametro de salida: p_RSP
   *      Contiene:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-11-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE ESTANISALUD_Acu(p_datreg      IN EST_ANU_PAI_SALUD%ROWTYPE
                            ,p_RSP         OUT    VARCHAR2 )
   IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;
      v_id                  EST_ANU_SALUD.ID%TYPE;
   
    -- Declaracin de excepciones
      er_null             EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'ESTANISALUD_Acu';    
      v_log := 'p_datreg.ANIO ->' || p_datreg.ANIO                
               ||', p_datreg.CIUSCONA ->' || p_datreg.CIUSCONA
               ||', p_datreg.CALSCIUS ->' || p_datreg.CALSCIUS
               ||', p_datreg.PASCIUS ->' || p_datreg.PASCIUS
               ||', p_datreg.HPACIUS ->' || p_datreg.HPACIUS
               ||', p_datreg.PERMAXCAL ->' || p_datreg.PERMAXCAL;
      p_RSP := ' ';       
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF  p_datreg.ANIO IS NULL
       OR p_datreg.CALSCIUS IS NULL
       OR p_datreg.PASCIUS IS NULL
       OR p_datreg.HPACIUS IS NULL
       THEN
          RAISE er_null;
      END IF;
      
      v_id := UTILIDADES.EST_ANU_SALUD_GetID(p_datreg.ANIO);
      
       IF p_datreg.CIUSCONA IS NULL THEN
         IF v_id IS NULL THEN
            INSERT INTO EST_ANU_SALUD(ANIO, CALSCIUS, PASCIUS, HPACIUS
                       ,PERMAXCAL)
               VALUES (p_datreg.ANIO, p_datreg.CALSCIUS, p_datreg.PASCIUS
                     , p_datreg.HPACIUS, p_datreg.PERMAXCAL);
         ELSE
            UPDATE EST_ANU_SALUD 
              SET CALSCIUS = p_datreg.CALSCIUS,
                  PASCIUS = p_datreg.PASCIUS,
                  HPACIUS = p_datreg.HPACIUS,
                  PERMAXCAL = p_datreg.PERMAXCAL
            WHERE ID = v_id;
         END IF;
       ELSE
         IF v_id IS NULL THEN
            INSERT INTO EST_ANU_SALUD(ANIO, CIUSCONA, CALSCIUS, PASCIUS
                       ,HPACIUS, PERMAXCAL)
               VALUES (p_datreg.ANIO, p_datreg.CIUSCONA, p_datreg.CALSCIUS
                     , p_datreg.PASCIUS, p_datreg.HPACIUS, p_datreg.PERMAXCAL);
         ELSE
            UPDATE EST_ANU_SALUD 
              SET CIUSCONA = p_datreg.CIUSCONA,
                  CALSCIUS = p_datreg.CALSCIUS,
                  PASCIUS = p_datreg.PASCIUS,
                  HPACIUS = p_datreg.HPACIUS,
                  PERMAXCAL = p_datreg.PERMAXCAL
            WHERE ID = v_id;
         END IF;
      END IF;
     -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      p_RSP := 'OK';
      v_log := v_log || ', v_id -> '|| v_id;
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);     
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg; 
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END ESTANISALUD_Acu;     
 /* ***************************************************************************
   *  Descripcin: Proporciona el valor de las columnas a contibilizar 
                   a la tabla EST_ANU_PAI_SALUD.
   *  Parametros entrada:
   *   p_datreg   - Registro con los datos a contibilizar
   *      si cantidad a acumular es mayor que 0 el trigger de columna indicada
   *       incrementa.
   *      si cantidad a acumular es menor que 0 el trigger de columna indicada
   *       decrementa.
   *  Parametro de salida: p_RSP
   *      Contiene:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-11-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE ESTANIPAISALUD_Acu(p_datreg      IN EST_ANU_PAI_SALUD%ROWTYPE
                               ,p_RSP         OUT    VARCHAR2 )
   IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;
      v_id                  EST_ANU_PAI_SALUD.ID%TYPE;
   
      -- Declaracin de excepciones
      er_null             EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'ESTANIPAISALUD_Acu';    
      v_log := 'p_datreg.ANIO ->' || p_datreg.ANIO    
               ||', p_datreg.CODPAIS ->' || p_datreg.CODPAIS
               ||', p_datreg.CIUSCONA ->' || p_datreg.CIUSCONA
               ||', p_datreg.CALSCIUS ->' || p_datreg.CALSCIUS
               ||', p_datreg.PASCIUS ->' || p_datreg.PASCIUS
               ||', p_datreg.HPACIUS ->' || p_datreg.HPACIUS
               ||', p_datreg.PERMAXCAL ->' || p_datreg.PERMAXCAL;
      p_RSP := ' ';       
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF  p_datreg.ANIO IS NULL
       OR p_datreg.CODPAIS IS NULL
       OR p_datreg.CALSCIUS IS NULL
       OR p_datreg.PASCIUS  IS NULL
       OR p_datreg.HPACIUS  IS NULL
         THEN
          RAISE er_null;
      END IF;
      
      v_id := UTILIDADES.EST_ANU_PAI_SALUD_GetID(p_datreg.ANIO, p_datreg.CODPAIS);
      
       IF p_datreg.CIUSCONA IS NULL THEN
         IF v_id IS NULL THEN
            INSERT INTO EST_ANU_PAI_SALUD(ANIO, CODPAIS, CALSCIUS, PASCIUS
                                         ,HPACIUS,PERMAXCAL)
               VALUES (p_datreg.ANIO, p_datreg.CODPAIS, p_datreg.CALSCIUS
                      ,p_datreg.PASCIUS, p_datreg.HPACIUS, p_datreg.PERMAXCAL);
         ELSE
            UPDATE EST_ANU_PAI_SALUD 
              SET CALSCIUS = p_datreg.CALSCIUS,
                  PASCIUS = p_datreg.PASCIUS,
                  HPACIUS = p_datreg.HPACIUS,
                  PERMAXCAL = p_datreg.PERMAXCAL
            WHERE ID = v_id;
         END IF;
       ELSE
         IF v_id IS NULL THEN         
            INSERT INTO EST_ANU_PAI_SALUD(ANIO, CODPAIS, CIUSCONA, CALSCIUS
                                         ,PASCIUS, HPACIUS,PERMAXCAL)
               VALUES (p_datreg.ANIO, p_datreg.CODPAIS, p_datreg.CIUSCONA
                      ,p_datreg.CALSCIUS, p_datreg.PASCIUS, p_datreg.HPACIUS
                      ,p_datreg.PERMAXCAL);
         ELSE
            UPDATE EST_ANU_PAI_SALUD 
              SET CIUSCONA = p_datreg.CIUSCONA,
                  CALSCIUS = p_datreg.CALSCIUS,
                  PASCIUS = p_datreg.PASCIUS,
                  HPACIUS = p_datreg.HPACIUS,
                  PERMAXCAL = p_datreg.PERMAXCAL
             WHERE ID = v_id;
         END IF;
      END IF;
     --  Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      p_RSP := 'OK';
      v_log := v_log || ', v_id -> '|| v_id;
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);     
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg; 
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END ESTANIPAISALUD_Acu;     
   /* ***************************************************************************
   *  Descripcin: Acumula el valor de columna indicadaa de la tabla EST_ANU_SALUD
   *  Parametros entrada:
   *   p_anio    - Ao de estadistico
   *   p_column  - Columna a actualizar
   *   p_acu     - Cantidad a acumular:
   *                si es mayor que 0 el trigger de columna indicada incrementa.
   *                si es menor que 0 el trigger de columna indicada decrementa.
   *  Parametro de salida: p_RSP
   *      Contiene:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         12-11-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE ESTSALUD_COLUMN_Acu(p_anio        IN EST_ANU_SALUD.ANIO%TYPE
                                ,p_column      IN VARCHAR2
                                ,p_acu         IN NUMBER DEFAULT 0
                                ,p_RSP         OUT    VARCHAR2 )
   IS      
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;
      v_id                  EST_ANU_SALUD.ID%TYPE;
      v_sql_stm             VARCHAR2(200);
   
    -- Declaracin de excepciones
      er_null             EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'ESTSALUD_COLUMN_Acu';    
      v_log :=    'p_anio ->' || p_anio                
                ||', p_column ->' || p_column
                ||', p_acu ->' || p_acu;
      p_RSP := ' ';       
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF p_anio IS NULL        
         THEN
          RAISE er_null;
      END IF;
      
      v_id := UTILIDADES.EST_ANU_SALUD_GetID(p_anio);
        
      IF p_column='ELEVCIUS' THEN
         -- Se proporciona la cantidad a acumular el resto lo har el trigger de ELEVCIUS
         IF v_id IS NULL THEN
            INSERT INTO EST_ANU_SALUD(ANIO, ELEVCIUS)
               VALUES (p_anio, p_acu);
         ELSE
            UPDATE EST_ANU_SALUD 
              SET ELEVCIUS = p_acu
            WHERE ID = v_id;
         END IF;
      END IF;      
      -- Si es una columna estadistica de tipo enfermedad grave (ENFERMEDADES)
      IF UTILIDADES.ENFERMEDADES_Found(p_column)='S' THEN
         -- Se proporciona la cantidad a acumular el resto lo har el trigger
         IF v_id IS NULL THEN
            v_sql_stm := 'INSERT INTO EST_ANU_SALUD(ANIO,' || p_column || ')
                          VALUES ('||p_anio||','|| p_acu||')';               
         ELSE
             v_sql_stm := 'UPDATE EST_ANU_SALUD SET '|| p_column || ' = '|| p_acu||
                           ' WHERE ID = ' || v_id;
         END IF;
         EXECUTE IMMEDIATE v_sql_stm;
      END IF;
      -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id y confirmamos      
      p_RSP := 'OK';
      v_log := v_log || ', v_id -> '|| v_id;
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);     
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg; 
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END ESTSALUD_COLUMN_Acu; 
   
   /* ***************************************************************************
   *  Descripcin: Acumula valor de columna indicada de la tabla EST_ANU_PAI_SALUD
   *  Parametros entrada:
   *   p_anio    - Ao de estadistico
   *   p_codpais - Cdigo de pais
   *   p_column  - Columna a actualizar
   *   p_acu     - Cantidad a acumular:
   *                si es mayor que 0 el trigger de columna indicada incrementa.
   *                si es menor que 0 el trigger de columna indicada decrementa.
   *  Parametro de salida: p_RSP
   *      Contiene:
   *                'OK' - > si la ejecucin ha sido correcta
   *                'ERROR '+ TIPO DE ERROR -> si la ejecucin es erronea
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         07-11-2014  Creacin procedimiento    
   ****************************************************************************/
   PROCEDURE ESTSALUD_COLUMN_Acu(p_anio      IN EST_ANU_PAI_SALUD.ANIO%TYPE
                              ,p_codpais     IN EST_ANU_PAI_SALUD.CODPAIS%TYPE
                              ,p_column      IN VARCHAR2
                              ,p_acu         IN NUMBER DEFAULT 0
                              ,p_RSP         OUT    VARCHAR2 )
   IS
      -- Declaracin de variables                   
      v_nompro            VARCHAR2 (50);
      v_log               VARCHAR2 (500);      
      
      v_err_msg             VARCHAR2 (256);
      v_err_num             NUMBER;
      v_id                  EST_ANU_PAI_SALUD.ID%TYPE;
      v_sql_stm             VARCHAR2(200);
   
    -- Declaracin de excepciones
      er_null             EXCEPTION;
   BEGIN
   -- Guardar parametros de entrada inicial en LOGS
      v_nompro := 'ESTSALUD_COLUMN_Acu';    
      v_log :=    'p_anio ->' || p_anio                
                ||', p_codpais ->' || p_codpais
                ||', p_column ->' || p_column
                ||', p_acu ->' || p_acu;
      p_RSP := ' ';       
      UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',p_RSP);
        
      --Verificar que los campos obligatorios no estn a null
      IF p_anio IS NULL        
         OR p_codpais IS NULL
         THEN
          RAISE er_null;
      END IF;
      
      v_id := UTILIDADES.EST_ANU_PAI_SALUD_GetID(p_anio, p_codpais);
      
     IF p_column='ELEVCIUS' THEN
         -- Se proporciona la cantidad a acumular el resto lo har el trigger de ELEVCIUS
         IF v_id IS NULL THEN
            INSERT INTO EST_ANU_PAI_SALUD(ANIO,CODPAIS, ELEVCIUS)
               VALUES (p_anio, p_codpais, p_acu);
         ELSE
            UPDATE EST_ANU_PAI_SALUD 
              SET ELEVCIUS = p_acu
            WHERE ID = v_id;
         END IF;
      END IF;
      -- Si es una columna estadistica de tipo enfermedad grave (ENFERMEDADES)
      IF UTILIDADES.ENFERMEDADES_Found(p_column)='S' THEN
         -- Se proporciona la cantidad a acumular el resto lo har el trigger
         IF v_id IS NULL THEN
            v_sql_stm := 'INSERT INTO EST_ANU_PAI_SALUD(ANIO,' || p_column || ')
                          VALUES ('||p_anio||','|| p_acu||')';               
         ELSE
             v_sql_stm := 'UPDATE EST_ANU_PAI_SALUD SET '|| p_column || ' = '|| p_acu||
                           ' WHERE ID = ' || v_id;
         END IF;
         EXECUTE IMMEDIATE v_sql_stm;
      END IF;      
      -- Si todo es correcto guardamos 'OK' en LOGS, informamos nueva id    
      p_RSP := 'OK';
      v_log := v_log || ', v_id -> '|| v_id;
      UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',p_RSP);
     
   EXCEPTION
      WHEN er_null THEN
         v_err_num := 1;
         v_err_msg := UTILIDADES.ERRORES_GetByID(v_err_num);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - ' || v_err_msg;
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
      WHEN OTHERS THEN
         v_err_num := SQLCODE;
         v_err_msg := SUBSTR (SQLERRM, 1, 100);
         p_RSP := 'ERROR ' || TO_CHAR (v_err_num) || ' - [SQLERR] ' || v_err_msg; 
         UTILIDADES. LOGS_Add(v_nompro, v_log, 'F','S',p_RSP);
         DBMS_OUTPUT.PUT_LINE (p_RSP);      
   END ESTSALUD_COLUMN_Acu;   
   
 /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve una cadena
   *      Contiene:
   *                'S' - > si encontrado
   *                'N' - > si no encontrado
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_GetPerMaxCal(p_anio IN INTEGER)
  RETURN CIUDADANOS.IDPERSONA%TYPE IS
  CURSOR c_bus IS
    SELECT fnd 
    FROM (
          SELECT ACT.ANIOACT, ACT.IDPERSONA fnd,SUM(ACT.CALORIAS) TOTALCAL 
           FROM W_CONSULTAR_ACT_DIARIA_PERSONA ACT
          WHERE ACT.ANIOACT = p_anio 
          GROUP BY ACT.ANIOACT, ACT.IDPERSONA
          ORDER BY SUM(ACT.CALORIAS) DESC
       )
    WHERE ROWNUM<=1;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd  CIUDADANOS.IDPERSONA%TYPE;
  v_RSP         VARCHAR2(500);
  BEGIN
    v_nompro := 'ACT_DIARIA_GetPerMaxCal';    
    v_log := 'p_anio ->' || p_anio;                
    v_RSP := ' ';       
      
    UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_GetPerMaxCal;


/* ***************************************************************************
   *  Descripcin: Devuelve la persona de un pais con mas calorias consumidas
   *               al ao.
   *  Parametro entrada:
   *      p_anio    = Ao a evaluar
   *      p_codpais = Pais a evaluar 
   *  Devuelve una cadena
   *      Contiene:
   *                'S' - > si encontrado
   *                'N' - > si no encontrado
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_GetPerMaxCal(p_anio IN INTEGER, p_codpais IN PAISES.COD%TYPE)
  RETURN CIUDADANOS.IDPERSONA%TYPE IS
  CURSOR c_bus IS
    SELECT fnd 
    FROM (
          SELECT ACT.ANIOACT, CS.CODPAIS, ACT.IDPERSONA fnd,SUM(ACT.CALORIAS) TOTALCAL 
           FROM W_CONSULTAR_ACT_DIARIA_PERSONA ACT, CENTROS_SALUD CS
          WHERE ACT.ANIOACT = p_anio 
           AND  ACT.IDCENTRO = CS.ID
          AND CS.CODPAIS = p_codpais
          GROUP BY ACT.ANIOACT, CS.CODPAIS, ACT.IDPERSONA
          ORDER BY SUM(ACT.CALORIAS) DESC
       )
    WHERE ROWNUM<=1;                       
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd  CIUDADANOS.IDPERSONA%TYPE;
  v_RSP         VARCHAR2(500);
  BEGIN
    v_nompro := 'ACT_DIARIA_GetPerMaxCal';    
    v_log := 'p_anio ->' || p_anio                
           ||', p_codpais ->' || p_codpais;
    v_RSP := ' ';       
     
    UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
        
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_GetPerMaxCal;

/* ***************************************************************************
   *  Descripcin: Devuelve el nmero de personas de un pais de la enfermedad
   *               indicada en un ao.             
   *  Parametro entrada:
   *      p_enf     = Identificador de enfermedad a evaluar
   *      p_anio    = Ao a evaluar
   *      p_codpais = Pais a evaluar 
   *  Devuelve una cadena
   *      Contiene:
   *                'S' - > si encontrado
   *                'N' - > si no encontrado
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         15-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION HISSALUD_ENF_GetCiusE(p_enf IN ENFERMEDADES.ID%TYPE
                               ,p_anio IN HIS_SALUD.ANIO%TYPE
                               ,p_codpais IN PAISES.COD%TYPE)
  RETURN INTEGER IS
  
  CURSOR c_bus IS  
  SELECT COUNT(*) fnd
     FROM HISSALUD_ENF HE
      ,HIS_SALUD HS
      ,CIUDADANOS CI
      ,CENTROS_SALUD CE
   WHERE HE.IDHIS=HS.ID 
     AND HS.IDCIU=CI.ID
     AND CI.IDCENTRO=CE.ID
     AND HS.ANIO = p_anio
     AND CE.CODPAIS= p_codpais
     AND HE.IDENF= p_enf;
  
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd INTEGER;
  v_RSP VARCHAR2(500);
  BEGIN
  v_nompro := 'HISSALUD_ENF_GetCiusE';    
  v_log := 'p_enf ->' || p_enf                
          ||', p_anio ->' || p_anio
          ||', p_codpais ->' || p_codpais;
   v_RSP := ' ';       
   
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   RETURN v_fnd;
  END HISSALUD_ENF_GetCiusE;
/* ***************************************************************************
   *  Descripcin: Devuelve el nmero de personas de un pais de la enfermedad
   *               indicada en un ao.             
   *  Parametro entrada:
   *      p_enf     = Identificador de enfermedad a evaluar
   *      p_anio    = Ao a evaluar
   *  Devuelve una cadena
   *      Contiene:
   *                'S' - > si encontrado
   *                'N' - > si no encontrado
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         15-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION HISSALUD_ENF_GetCiusE(p_enf IN ENFERMEDADES.ID%TYPE
                               ,p_anio IN HIS_SALUD.ANIO%TYPE)
  RETURN INTEGER IS
  
  CURSOR c_bus IS  
  SELECT COUNT(*) fnd
  FROM HISSALUD_ENF HE
      ,HIS_SALUD HS
  WHERE HE.IDHIS=HS.ID 
    AND HS.ANIO = p_anio
    AND HE.IDENF = p_enf;
    
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      

  v_fnd INTEGER;
  v_RSP VARCHAR2(500);
  
  BEGIN
   v_nompro := 'HISSALUD_ENF_GetCiusE';    
   v_log := 'p_enf ->' || p_enf                
          ||', p_anio ->' || p_anio;
   v_RSP := ' ';            
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END HISSALUD_ENF_GetCiusE;
  
    /* ***************************************************************************
   *  Descripcin: Busca si un ciudadano tiene actividad diaria tabla ACT_DIARIA
   *  Parametro entrada:
   *      p_idciu = Identificador de ciudadano
   *      p_anio    = Ao a evaluar
   *  Devuelve nmero de ocurrencias
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         04-10-2014  Creacin funcin    
   ****************************************************************************/
  FUNCTION ACT_DIARIA_CFound(p_idciu IN ACT_DIARIA.IDCIU%TYPE
                            ,p_anio IN INTEGER)
  RETURN INTEGER IS
  CURSOR c_bus IS
    SELECT COUNT(AD.IDCIU) AS fnd 
      FROM W_CONSULTAR_ACT_DIARIA AD
      WHERE AD.IDCIU = p_idciu
        AND AD.ANIOACT= p_anio;
        
  v_bus  c_bus%ROWTYPE;
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      

  v_fnd INTEGER;
  v_RSP VARCHAR2(500);
  
  BEGIN
  v_nompro := 'ACT_DIARIA_CFound';    
   v_log := 'p_idciu ->' || p_idciu               
          ||', p_anio ->' || p_anio;
   v_RSP := ' ';       
   DBMS_OUTPUT.PUT_LINE ('1. '|| p_idciu||'*'|| p_anio ||'#');      
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_CFound;
  
  /* ***************************************************************************
   *  Descripcin: Busca si un ciudadano tiene actividad diaria tabla ACT_DIARIA
   *  Parametro entrada:
   *      p_idciu = Identificador de ciudadano
   *      p_anio    = Ao a evaluar
   *      p_codpais = Pais a evaluar 
   *  Devuelve nmero de ocurrencias
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         04-10-2014  Creacin funcin    
   ****************************************************************************/
  FUNCTION ACT_DIARIA_CFound(p_idciu IN ACT_DIARIA.IDCIU%TYPE
                            ,p_anio IN INTEGER
                            ,p_codpais IN PAISES.COD%TYPE)
  RETURN INTEGER IS
  CURSOR c_bus IS
    SELECT COUNT(AD.IDCIU) AS fnd 
      FROM W_CONSULTAR_ACT_DIARIA_PERSONA AD
          ,CENTROS_SALUD CS
      WHERE AD.IDCIU = p_idciu
        AND AD.ANIOACT= p_anio
        AND AD.IDCENTRO=CS.ID
        AND CS.CODPAIS= p_codpais;
  v_bus  c_bus%ROWTYPE;
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      

  v_fnd INTEGER;
  v_RSP VARCHAR2(500);
  
  BEGIN
  v_nompro := 'ACT_DIARIA_CFound';    
   v_log := 'p_idciu ->' || p_idciu               
          ||', p_anio ->' || p_anio
          ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';       
        
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN      
        v_fnd:=v_bus.fnd;
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_CFound;
    /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_CIUSCONA(p_anio IN INTEGER)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT COUNT(*) fnd 
       FROM W_CONSULTAR_ACT_DIARIA ACT 
       WHERE ACT.ANIOACT = p_anio 
       GROUP BY ACT.ANIOACT;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP         VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_CIUSCONA';    
   v_log := 'p_anio ->' || p_anio;                
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_CIUSCONA;
 
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_CALSCIUS(p_anio IN INTEGER)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.CALORIAS) fnd
       FROM W_CONSULTAR_ACT_DIARIA ACT 
       WHERE ACT.ANIOACT = p_anio 
       GROUP BY ACT.ANIOACT;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_CALSCIUS';    
   v_log := 'p_anio ->' || p_anio;                
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_CALSCIUS;
  
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_PASCIUS(p_anio IN INTEGER)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.PASOS) fnd
       FROM W_CONSULTAR_ACT_DIARIA ACT 
       WHERE ACT.ANIOACT = p_anio 
       GROUP BY ACT.ANIOACT;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_PASCIUS';    
   v_log := 'p_anio ->' || p_anio;                
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_PASCIUS;
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_HPACIUS(p_anio IN INTEGER)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.HPOCACT) fnd
       FROM W_CONSULTAR_ACT_DIARIA ACT 
       WHERE ACT.ANIOACT = p_anio 
       GROUP BY ACT.ANIOACT;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_HPACIUS';    
   v_log := 'p_anio ->' || p_anio;                
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:= NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_HPACIUS;
    /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION HIS_SALUD_ELEVCIUS(p_anio IN INTEGER)
 RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(HIS.ENFLEVS) fnd
       FROM HIS_SALUD HIS 
       WHERE ANIO = p_anio;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'HIS_SALUD_ELEVCIUS';    
   v_log := 'p_anio ->' || p_anio;                
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:= NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END HIS_SALUD_ELEVCIUS;
  
   /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_CIUSCONA(p_anio IN INTEGER, p_codpais IN VARCHAR2)
  RETURN INTEGER IS
  CURSOR c_bus IS     
       SELECT COUNT(*) fnd
       FROM W_CONSULTAR_ACT_DIARIA ACT,
            W_CONSULTAR_CIUDADANOS CIU
       WHERE ACT.IDCIU=CIU.ID 
         AND ACT.ANIOACT = p_anio
         AND CIU.CODPAIS = p_codpais;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP         VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_CIUSCONA';    
   v_log := 'p_anio ->' || p_anio
          ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);
   
   RETURN v_fnd;
  END ACT_DIARIA_CIUSCONA;
 
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_CALSCIUS(p_anio IN INTEGER, p_codpais IN VARCHAR2)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.CALORIAS) fnd
        FROM W_CONSULTAR_ACT_DIARIA ACT,
             W_CONSULTAR_CIUDADANOS CIU
       WHERE ACT.IDCIU=CIU.ID 
         AND ACT.ANIOACT = p_anio
         AND CIU.CODPAIS = p_codpais;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_CALSCIUS';    
   v_log := 'p_anio ->' || p_anio
          ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_CALSCIUS;
  
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_PASCIUS(p_anio IN INTEGER, p_codpais IN VARCHAR2)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.PASOS) fnd
        FROM W_CONSULTAR_ACT_DIARIA ACT,
             W_CONSULTAR_CIUDADANOS CIU
       WHERE ACT.IDCIU=CIU.ID 
         AND ACT.ANIOACT = p_anio
         AND CIU.CODPAIS = p_codpais;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_PASCIUS';    
   v_log := 'p_anio ->' || p_anio
          ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:=NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_PASCIUS;
  /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION ACT_DIARIA_HPACIUS(p_anio IN INTEGER, p_codpais IN VARCHAR2)
  RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(ACT.HPOCACT) fnd
       FROM W_CONSULTAR_ACT_DIARIA ACT,
            W_CONSULTAR_CIUDADANOS CIU
       WHERE ACT.IDCIU=CIU.ID 
         AND ACT.ANIOACT = p_anio
         AND CIU.CODPAIS = p_codpais;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'ACT_DIARIA_HPACIUS';    
   v_log := 'p_anio ->' || p_anio
        ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:= NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END ACT_DIARIA_HPACIUS;
    /* ***************************************************************************
   *  Descripcin: Devuelve la persona con mas calorias consumidas al ao.
   *  Parametro entrada:
   *      p_anio = Ao a evaluar
   *  Devuelve numero de ciudadanos con actividad fisica registrada
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         14-10-2014  Creacin funcin    
   ****************************************************************************/
 FUNCTION HIS_SALUD_ELEVCIUS(p_anio IN INTEGER, p_codpais IN VARCHAR2)
 RETURN INTEGER IS
  CURSOR c_bus IS
       SELECT SUM(HIS.ENFLEVS) fnd
       FROM W_CONSULTAR_HIS_SALUD HIS,
            W_CONSULTAR_CIUDADANOS CIU
       WHERE HIS.IDCIU = CIU.ID
         AND HIS.ANIO = p_anio
         AND CIU.CODPAIS = p_codpais;
  v_bus  c_bus%ROWTYPE;
  
  -- Declaracin de variables                   
  v_nompro            VARCHAR2 (50);
  v_log               VARCHAR2 (500);      
  v_fnd               INTEGER;
  v_RSP               VARCHAR2(500);
  BEGIN
   v_nompro := 'HIS_SALUD_ELEVCIUS';    
   v_log := 'p_anio ->' || p_anio 
        ||', p_codpais ->'|| p_codpais;
   v_RSP := ' ';          
   UTILIDADES. LOGS_Add(v_nompro, v_log, 'I','N',v_RSP);
   v_fnd:=0;   
   OPEN c_bus;
   FETCH c_bus INTO v_bus;
   IF c_bus%FOUND THEN 
        v_fnd:= NVL(v_bus.fnd,0);
   END IF;
   CLOSE c_bus;
   v_RSP := 'OK';
   v_log:= v_log || ', RETURN '|| v_fnd;
   UTILIDADES.LOGS_Add(v_nompro, v_log, 'F','N',v_RSP);   
   RETURN v_fnd;
  END HIS_SALUD_ELEVCIUS;
--
END ESTADISTICA;
/
