CREATE OR REPLACE PACKAGE LISTADOS AS
-- Listado estado ciudadanos (requisito) 5 --
TYPE ESTADOSALUD IS RECORD(
    IDCIU       INTEGER  -- Identificacin de ciudadano evaluado.
   ,VISITASMED  INTEGER  -- Nmero de visitas al mdico realizadas.
   ,MEDCALS     INTEGER  -- Media de caloras gastadas cada da. 
   ,ANIOECAR    INTEGER  -- Ao de diagnstico de enfermedad cardaca
   ,ANIOECAN    INTEGER  -- Ao de diagnstico de enfermedad cancergena
   ,ANIOEDEG    INTEGER  -- Ao de diagnstico de enfermedad degenerativa
   ,ENFLEVS     INTEGER  -- Nmero de enfermedades leves diagnosticadas
 );
TYPE ESTADOSSALUD IS TABLE OF ESTADOSALUD;

FUNCTION CIUDADANOS_EstadoSalud(p_anio IN INTEGER
                               ,p_codpais IN PAISES.COD%TYPE
                               ,p_edad IN INTEGER
                               ,p_limcal IN INTEGER)
RETURN ESTADOSSALUD PIPELINED;
-----------------
-- Listado seguimiento mensual del ciudadano requisito 6 --
TYPE SEGMES IS RECORD(
    MES         INTEGER  -- Mes estudiado
   ,TOTPASOS    INTEGER  -- Suma de nmero de pasos realizados.
   ,MEDCALS     INTEGER  -- Media de nmero de caloras gastadas por da. 
   ,TOTHPOCACT  INTEGER  -- Suma de nmero de horas de poca actividad 
 );
TYPE SEGMENSUAL IS TABLE OF SEGMES;

FUNCTION ACT_DIARIA_SegMensual(p_idciu IN CIUDADANOS.ID%TYPE
                               ,p_anio IN INTEGER)
RETURN SEGMENSUAL PIPELINED;
-----------------
-- Listado estudios de los ciudadanos europeos requisito 7 --
TYPE ESTPAIS IS RECORD(
    CODPAIS     VARCHAR2(2) -- Pais estudiado
   ,MEDPASOS    INTEGER     -- Media de nmero de pasos realizados por da. 
   ,MEDCALS     INTEGER     -- Media de nmero de caloras gastadas por da. 
   ,MEDHPOCACT  INTEGER     -- Media de nmero de horas de poca actividad. 
 );
TYPE ESTEUROPA IS TABLE OF ESTPAIS;

FUNCTION ACT_DIARIA_EstEuropa(p_anio IN INTEGER
                             ,p_edad IN INTEGER)
RETURN ESTEUROPA PIPELINED;
END LISTADOS;
/
CREATE OR REPLACE PACKAGE BODY LISTADOS AS
  /* ***************************************************************************
   *  Descripcin: Devuelve un listado con el estado de salud de los ciudadanos
                   de un pais, durante una ao y que tienen la edad indicada (R5)
   *  Parametro entrada: 
   *      p_anio    = Ao a evaluar
   *      p_codpais = Pais a evaluar 
   *      p_edad    = Edad a evaluar
   *      p_limcal  = Lmite de caloras
   *  Devuelve listado de registros con:
   *   IDCIU       INTEGER  =  Identificacin de ciudadano evaluado.
   *   VISITASMED  INTEGER  =  Nmero de visitas al mdico realizadas.
   *   MEDCALS     INTEGER  =  Media de caloras gastadas cada da. 
   *   ANIOECAR    INTEGER  =  Ao de diagnstico de enfermedad cardaca
   *   ANIOECAN    INTEGER  =  Ao de diagnstico de enfermedad cancergena
   *   ANIOEDEG    INTEGER  =  Ao de diagnstico de enfermedad degenerativa
   *   ENFLEVS     INTEGER  =  Nmero de enfermedades leves diagnosticadas
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         20-11-2014  Creacin funcin  
   * Mari Cruz         30-11-2014  Optimitacin consultas
   ****************************************************************************/
  FUNCTION CIUDADANOS_EstadoSalud(p_anio IN INTEGER
                               ,p_codpais IN PAISES.COD%TYPE
                               ,p_edad IN INTEGER
                               ,p_limcal IN INTEGER)
 RETURN ESTADOSSALUD PIPELINED
 IS
  CURSOR c_bus IS
   SELECT CI.ID CIU
        ,CI.CODPAIS
        ,HS.ID,HS.ANIO, HS.VISITASMED, HS.ENFLEVS        
   FROM W_CONSULTAR_CIUDADANOS CI
       ,HIS_SALUD HS
   WHERE (CI.FECHABAJ IS NULL 
      OR EXTRACT(YEAR FROM CI.FECHABAJ) >= p_anio)
     AND CI.ID = HS.IDCIU 
     AND HS.ANIO = p_anio
     AND CI.CODPAIS = p_codpais
     AND CI.EDAD = p_edad;
  v_bus  c_bus%ROWTYPE;
  
   CURSOR c_avg (p_ciuact CIUDADANOS.ID%TYPE, p_anioact INTEGER) IS
     SELECT CAST(avg(CALORIAS) AS INTEGER) MEDCAL
      FROM W_CONSULTAR_ACT_DIARIA
      WHERE ANIOACT = p_anioact
       AND IDCIU = p_ciuact;       
  v_avg  c_avg%ROWTYPE;
  
   CURSOR c_aenf (p_ciuhis CIUDADANOS.ID%TYPE, p_enf INTEGER) IS  
      SELECT ANIO
         FROM W_CONSULTAR_HIS_SALUD
      WHERE IDCIU = p_ciuhis
        AND IDENF = p_enf
     ORDER BY ANIO DESC;
     
  v_aenf  c_aenf%ROWTYPE;
  
  -- Declaracin de variables                    
  v_medcals           INTEGER;

  v_row   ESTADOSALUD;

  BEGIN   
   FOR v_bus IN c_bus
   LOOP   
     -- Obtener ciudadano evaluado
       v_row.IDCIU := v_bus.CIU;
     -- Obtenmos nmero de visitas al mdico realizadas por el ciudadano aquel ao
       v_row.VISITASMED := v_bus.VISITASMED;
     --	Obtener media de caloras gastadas cada da en aquel ao    
       OPEN c_avg(v_bus.CIU, p_anio);
       FETCH c_avg INTO v_avg;
       IF c_avg%FOUND THEN
          v_medcals := v_avg.MEDCAL;
       END IF;
       CLOSE c_avg;
     -- (siempre y cuando esta media de caloras est por debajo del lmite 
     --  de caloras pasado por parmetro).
     IF v_medcals < p_limcal THEN
        v_row.MEDCALS := v_medcals;
     END IF;         
     -- Detalle de enfermedades graves diagnosticadas :
      -- Primer ao de diagnstico de enfermedad cardaca 1
      v_row.ANIOECAR := NULL;      
       OPEN c_aenf(v_bus.CIU, 1);
       FETCH c_aenf INTO v_aenf;
       IF c_aenf%FOUND THEN
          v_row.ANIOECAR := v_aenf.ANIO;          
       END IF;
       CLOSE c_aenf;       
      -- Primer ao de diagnstico de enfermedad cancergena 2
       v_row.ANIOECAN := NULL;      
       OPEN c_aenf(v_bus.CIU, 2);
       FETCH c_aenf INTO v_aenf;
       IF c_aenf%FOUND THEN
          v_row.ANIOECAN := v_aenf.ANIO;          
       END IF;
       CLOSE c_aenf;       
      -- Primer ao de diagnstico de enfermedad degenerativa 3
       v_row.ANIOEDEG := NULL;      
       OPEN c_aenf(v_bus.CIU, 3);
       FETCH c_aenf INTO v_aenf;
       IF c_aenf%FOUND THEN
          v_row.ANIOEDEG := v_aenf.ANIO;          
       END IF;
       CLOSE c_aenf;       
    --	Nmero de enfermedades leves diagnosticadas.
        v_row.ENFLEVS := v_bus.enflevs;        
    --  Cargar linea en resultado
    PIPE ROW(v_row); 
   END LOOP; 
   
    RETURN;
  END CIUDADANOS_EstadoSalud;
  
  /* ***************************************************************************
   *  Descripcin: Devuelve listado con el seguimiento mensual de la actividad
                   diaria de un ciudadano durante un ao (R6)
   *  Parametro entrada: 
   *      p_idciu   = Identificacin ciudadano a evaluar
   *      p_anio    = Ao a evaluar
   *  Devuelve listado de registros con las siugientes columnas:
   *   MES         INTEGER  = Mes estudiado.
   *   TOTPASOS    INTEGER  = Suma de nmero de pasos realizados.
   *   MEDCALS     INTEGER  = Media de nmero de caloras gastadas por da. 
   *   TOTHPOCACT  INTEGER  = Suma de nmero de horas de poca actividad.
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         22-11-2014  Creacin funcin   
   * Mari Cruz         30-11-2014  Optimizacin de consulta
   ****************************************************************************/
FUNCTION ACT_DIARIA_SegMensual(p_idciu IN CIUDADANOS.ID%TYPE
                               ,p_anio IN INTEGER)
RETURN SEGMENSUAL PIPELINED
IS
  CURSOR c_bus IS
    SELECT AD.MESACT
          ,SUM(AD.PASOS)
          ,AVG(AD.CALORIAS)
          ,SUM(AD.HPOCACT)
    FROM W_CONSULTAR_ACT_DIARIA AD
    WHERE AD.IDCIU = p_idciu 
      AND AD.ANIOACT = p_anio      
     GROUP BY AD.IDCIU, AD.ANIOACT, AD.MESACT;
     
  v_bus  c_bus%ROWTYPE;
    
  BEGIN
   FOR v_bus IN c_bus
   LOOP          
    --  Cargar linea en resultado
     PIPE ROW(v_bus);
   END LOOP;
   
    RETURN;
END ACT_DIARIA_SegMensual;

 /* ***************************************************************************
   *  Descripcin: Devuelve listado por paises con la media de actividad diaria 
   *               durante el ao indicado de los ciudadanos europeos (R7)
   *  Parametro entrada: 
   *      p_anio    = Ao a evaluar
   *      p_edad    = Edad mxima del ciudadano para entrar en ambito de clculo
   *  Devuelve listado de registros con:
   *   CODPAIS     VARCHAR2 =  Pais estudiado
   *   MEDPASOS    INTEGER  =  Media de nmero de pasos realizados por da. 
   *   MEDCALS     INTEGER  =  Media de nmero de caloras gastadas por da. 
   *   MEDHPOCACT  INTEGER  =  Media de nmero de horas de poca actividad. 
   *
   *  Autor            Fecha creacin/modificacin
   *---------------------------------------------------------------------------
   * Mari Cruz         24-11-2014  Creacin funcin
   * Mari Cruz         30-11-2014  Optimizacin de consulta
   ****************************************************************************/
FUNCTION ACT_DIARIA_EstEuropa(p_anio IN INTEGER
                             ,p_edad IN INTEGER)
RETURN ESTEUROPA PIPELINED
IS
  CURSOR c_bus IS
  SELECT CI.CODPAIS
        ,AVG(AD.PASOS)
        ,AVG(AD.CALORIAS)
        ,AVG(AD.HPOCACT) 
  FROM W_CONSULTAR_ACT_DIARIA AD
      ,W_CONSULTAR_CIUDADANOS CI
      ,PAISES PA
  WHERE AD.ANIOACT = p_anio
    AND AD.IDCIU=CI.ID 
    AND CI.EDAD <= p_edad
    AND CI.CODPAIS=PA.COD    
    AND NOT PA.ANIOUE IS NULL
  GROUP BY CI.CODPAIS;
  
  v_bus  c_bus%ROWTYPE;
  -- Declaracin de variables                    
  v_medcals           INTEGER;

  v_row   ESTADOSALUD;

  BEGIN   
    FOR v_bus IN c_bus
   LOOP          
    --  Cargar linea en resultado
     PIPE ROW(v_bus);
   END LOOP;
 
    RETURN;
  END ACT_DIARIA_EstEuropa;
  
END LISTADOS;
/
